#=========================================================================#
#                                  PHYL                                   #
#=========================================================================#

# Phylloicus hansoni Size Structure Study

# Authors: David Stoker (dstoker92@gmail.com) & Kelly M. Murray (kmmurray@uga.edu)
# Last Updated: 5 August 2017

## Table of Contents
# Line   23 = Load Packages and Data
# Line   43 = Data Management
# Line  227 = Size Distribution Characteristics
# Line  504 = Size Structure Comparisons
# Line  890 = Stream Survey
# Line 1012 = Killifish Predation
# Line 1092 = Figures
# Line 1288 = End of Script


#=========================================================================#
#                          Load Packages and Data                         #
#==========================================================================
library(agricolae)
library(plyr)


setwd("~/Documents/Research/PHYL/CSV Files")

## Read in data
PHYL.data    <- read.csv("PHYL-size_frequency_data.csv")
survey.data  <- read.csv("PHYL-site_survey_data.csv")
GCA.data     <- read.csv("PHYL-GCA_data.csv")
fish.SC.data <- read.csv("PHYL-fish_size_class_data.csv")

source("~/Documents/Classes/MATH 6315/R Script-BSW/qqnormWithBounds.R")
# Source code provided by: 
# Dr. Blair Sterba-Boatwright
# Texas A & M University-Corpus Christi


#=========================================================================#
#                               Data Management                           #
#==========================================================================

# Aggregating and reformatting dataframes for analyses.

## Individual dataframes--------------------------------------------------#

# Dataframes for each individual streams for use in basic population 
# distribution characteristics

## Body length
CED.KG.length <- PHYL.data[PHYL.data$stream == "CED" & PHYL.data$reach == "KG", 4]
CED.KO.length <- PHYL.data[PHYL.data$stream == "CED" & PHYL.data$reach == "KO", 4]
END.KG.length <- PHYL.data[PHYL.data$stream == "END" & PHYL.data$reach == "KG", 4]
END.KO.length <- PHYL.data[PHYL.data$stream == "END" & PHYL.data$reach == "KO", 4]
GDC.KG.length <- PHYL.data[PHYL.data$stream == "GDC" & PHYL.data$reach == "KG", 4]
GDC.KO.length <- PHYL.data[PHYL.data$stream == "GDC" & PHYL.data$reach == "KO", 4]
RDN.KG.length <- PHYL.data[PHYL.data$stream == "RDN" & PHYL.data$reach == "KG", 4]
RDN.KO.length <- PHYL.data[PHYL.data$stream == "RDN" & PHYL.data$reach == "KO", 4]
TRT.KG.length <- PHYL.data[PHYL.data$stream == "TRT" & PHYL.data$reach == "KG", 4]
TRT.KO.length <- PHYL.data[PHYL.data$stream == "TRT" & PHYL.data$reach == "KO", 4]

## Head capsule width
CED.KG.HCW <- PHYL.data[PHYL.data$stream == "CED" & PHYL.data$reach == "KG", 5]
CED.KO.HCW <- PHYL.data[PHYL.data$stream == "CED" & PHYL.data$reach == "KO", 5]
END.KG.HCW <- PHYL.data[PHYL.data$stream == "END" & PHYL.data$reach == "KG", 5]
END.KO.HCW <- PHYL.data[PHYL.data$stream == "END" & PHYL.data$reach == "KO", 5]
GDC.KG.HCW <- PHYL.data[PHYL.data$stream == "GDC" & PHYL.data$reach == "KG", 5]
GDC.KO.HCW <- PHYL.data[PHYL.data$stream == "GDC" & PHYL.data$reach == "KO", 5]
RDN.KG.HCW <- PHYL.data[PHYL.data$stream == "RDN" & PHYL.data$reach == "KG", 5]
RDN.KO.HCW <- PHYL.data[PHYL.data$stream == "RDN" & PHYL.data$reach == "KO", 5]
TRT.KG.HCW <- PHYL.data[PHYL.data$stream == "TRT" & PHYL.data$reach == "KG", 5]
TRT.KO.HCW <- PHYL.data[PHYL.data$stream == "TRT" & PHYL.data$reach == "KO", 5]


## Full data (i.e. all five focal streams)--------------------------------#

## Aggregate median body length (BL) for by reach and stream
PHYL.data.BL.full <- aggregate(length ~ stream + reach, FUN = median, 
                          data = PHYL.data)

## Subset BL by KO and KG reaches
PHYL.data.BL.KO.full <- PHYL.data.BL.full[PHYL.data.BL.full$reach == "KO", 3]
PHYL.data.BL.KG.full <- PHYL.data.BL.full[PHYL.data.BL.full$reach == "KG", 3]


## Aggregate median head capsule width (HCW) by reach and stream
PHYL.data.HCW.full <- aggregate(HCW ~ stream + reach, FUN = median, 
                          data = PHYL.data)

## Subset HCW by KO and KG reaches
PHYL.data.HCW.KO.full <- PHYL.data.HCW.full[PHYL.data.HCW.full$reach == "KO", 3]
PHYL.data.HCW.KG.full <- PHYL.data.HCW.full[PHYL.data.HCW.full$reach == "KG", 3]


## Final Data (i.e. GDC removed)------------------------------------------#

## Aggregate median body length (BL) for by reach and stream
PHYL.data.BL.bin <- PHYL.data.BL.full[PHYL.data.BL.full$stream != "GDC", ]

PHYL.data.BL <- aggregate(length ~ stream + reach, FUN = median, 
                               data = PHYL.data.BL.bin)

## Subset BL by KO and KG reaches
PHYL.data.BL.KO <- PHYL.data.BL[PHYL.data.BL$reach == "KO", 3]
PHYL.data.BL.KG <- PHYL.data.BL[PHYL.data.BL$reach == "KG", 3]


## Aggregate median head capsule width (HCW) by reach and stream
PHYL.data.HCW.bin <- PHYL.data.HCW.full[PHYL.data.HCW.full$stream != "GDC", ]

PHYL.data.HCW <- aggregate(HCW ~ stream + reach, FUN = median, 
                                 data = PHYL.data.HCW.bin)

## Subset HCW by KO and KG reaches
PHYL.data.HCW.KO <- PHYL.data.HCW[PHYL.data.HCW$reach == "KO", 3]
PHYL.data.HCW.KG <- PHYL.data.HCW[PHYL.data.HCW$reach == "KG", 3]


## Body length (instars)--------------------------------------------------#
PHYL.body.length <- aggregate(length ~ instar.group + reach + stream, 
                                    FUN = median, data = PHYL.data[PHYL.data$stream != "GDC",])

## Subset body.length data by instar group (small = S, medium = M, large = L)
PHYL.body.length.S <- PHYL.body.length[PHYL.body.length$instar.group == "S", ]
PHYL.body.length.M <- PHYL.body.length[PHYL.body.length$instar.group == "M", ]
PHYL.body.length.L <- PHYL.body.length[PHYL.body.length$instar.group == "L", ]

## Further subset relative body.length data by reach
PHYL.body.length.S.KO <- PHYL.body.length.S[PHYL.body.length.S$reach == "KO", 4]
PHYL.body.length.S.KG <- PHYL.body.length.S[PHYL.body.length.S$reach == "KG", 4]

PHYL.body.length.M.KO <- PHYL.body.length.M[PHYL.body.length.M$reach == "KO", 4]
PHYL.body.length.M.KG <- PHYL.body.length.M[PHYL.body.length.M$reach == "KG", 4]

PHYL.body.length.L.KO <- PHYL.body.length.L[PHYL.body.length.L$reach == "KO", 4]
PHYL.body.length.L.KG <- PHYL.body.length.L[PHYL.body.length.L$reach == "KG", 4]


## Abundances (instars)---------------------------------------------------#
PHYL.abundance <- aggregate(count ~ instar.group + reach + stream, 
                            FUN = sum, data = PHYL.data[PHYL.data$stream != "GDC",])

## Calculating relative abundance (percentage) for later analyses
PHYL.abundance.STREAM <- aggregate(count ~ stream + reach, FUN = sum, 
                                   data = PHYL.data[PHYL.data$stream != "GDC",])

## CED KO = 54, CED KG = 127
## END KO = 88, END KG = 102
## RDN KO = 61, RDN KG = 185
## TRT KO = 78, TRT KG = 184

PHYL.abundance$relative.abundance <- 0
PHYL.abundance[1:3, 5]   <- (PHYL.abundance[1:3, 4]/127) * 100
PHYL.abundance[4:6, 5]   <- (PHYL.abundance[4:6, 4]/54) * 100
PHYL.abundance[7:9, 5]   <- (PHYL.abundance[7:9, 4]/102) * 100
PHYL.abundance[10:12, 5] <- (PHYL.abundance[10:12, 4]/88) * 100
PHYL.abundance[13:15, 5] <- (PHYL.abundance[13:15, 4]/185) * 100
PHYL.abundance[16:18, 5] <- (PHYL.abundance[16:18, 4]/61) * 100
PHYL.abundance[19:21, 5] <- (PHYL.abundance[19:21, 4]/184) * 100
PHYL.abundance[22:24, 5] <- (PHYL.abundance[22:24, 4]/78) * 100

## Subset abundance data by instar group (small = S, medium = M, large = L)
PHYL.abundance.S <- PHYL.abundance[PHYL.abundance$instar.group == "S", ]
PHYL.abundance.M <- PHYL.abundance[PHYL.abundance$instar.group == "M", ]
PHYL.abundance.L <- PHYL.abundance[PHYL.abundance$instar.group == "L", ]

## Further subset relative abundance data by reach
PHYL.abundance.S.KO <- PHYL.abundance.S[PHYL.abundance.S$reach == "KO", 5]
PHYL.abundance.S.KG <- PHYL.abundance.S[PHYL.abundance.S$reach == "KG", 5]

PHYL.abundance.M.KO <- PHYL.abundance.M[PHYL.abundance.M$reach == "KO", 5]
PHYL.abundance.M.KG <- PHYL.abundance.M[PHYL.abundance.M$reach == "KG", 5]

PHYL.abundance.L.KO <- PHYL.abundance.L[PHYL.abundance.L$reach == "KO", 5]
PHYL.abundance.L.KG <- PHYL.abundance.L[PHYL.abundance.L$reach == "KG", 5]


## Killifish Predation----------------------------------------------------#

## Percent of gut with P. hansoni present in the contents

## Number of successes per reach and stream
FISH.predation.success <- aggregate(success ~ stream + reach, 
                                    FUN = sum, data = GCA.data)

## Number of gut contents analyzed per stream
summary(GCA.data)

# CED = 19 (KO = 14, KG = 5)
# CSC = 23 (KO = 10, KG = 13)
# END = 21 (KO = 14, KG = 7)
# GDC = 29 (KO = 14, KG = 15)

FISH.predation.success$percent.success <- 0
FISH.predation.success[1, 4] <- (FISH.predation.success[1, 3]/5) * 100
FISH.predation.success[2, 4] <- (FISH.predation.success[2, 3]/13) * 100
FISH.predation.success[3, 4] <- (FISH.predation.success[3, 3]/7) * 100
FISH.predation.success[4, 4] <- (FISH.predation.success[4, 3]/15) * 100
FISH.predation.success[5, 4] <- (FISH.predation.success[5, 3]/14) * 100
FISH.predation.success[6, 4] <- (FISH.predation.success[6, 3]/10) * 100
FISH.predation.success[7, 4] <- (FISH.predation.success[7, 3]/14) * 100
FISH.predation.success[8, 4] <- (FISH.predation.success[8, 3]/14) * 100

## Subset BL by KO and KG reaches
FISH.predation.success.KO <- FISH.predation.success[FISH.predation.success$reach == "KO", 3]
FISH.predation.success.KG <- FISH.predation.success[FISH.predation.success$reach == "KG", 3]


## Median size of P. hansoni present in killifish gut contents
FISH.predation.HCW.bin.1 <- GCA.data[GCA.data$success == 1, ]

FISH.predation.HCW.bin.2 <- aggregate(HCW ~ stream + reach, 
                                      FUN = median, data = FISH.predation.HCW.bin.1)

## Remove CED as there is no paired observation in the KO reach
FISH.predation.HCW <- FISH.predation.HCW.bin.2[-1, ]

## Subset fish predation data by reach
FISH.predation.HCW.KO <- FISH.predation.HCW[FISH.predation.HCW$reach == "KO", 3]
FISH.predation.HCW.KG <- FISH.predation.HCW[FISH.predation.HCW$reach == "KG", 3]


#=========================================================================#
#                     Size Distribution Characteristics                   #
#==========================================================================

# Calculating median, interquartile range (IQR), skew, and kurtosis for 
# each population (i.e. by stream and reach)

#-------------------------------------------------------------------------#
#                              Median & IQR                               #
#--------------------------------------------------------------------------

#-------------------------------KO reaches--------------------------------#

## CED
# Body length
median(na.omit(CED.KO.length)) # median = 7.6
quantile(x = na.omit(CED.KO.length), probs = c(0.25, 0.75)) # 5.175, 10.375
# HCW
median(na.omit(CED.KO.HCW)) # median = 0.7
quantile(x = na.omit(CED.KO.HCW), probs = c(0.25, 0.75)) # 0.45, 1.00

## END
# Body length
median(na.omit(END.KO.length)) # median = 6.95
quantile(x = na.omit(END.KO.length), probs = c(0.25, 0.75)) # 4.50, 10.15
# HCW
median(na.omit(END.KO.HCW)) # median = 0.7
quantile(x = na.omit(END.KO.HCW), probs = c(0.25, 0.75)) # 0.6, 1.0 

## GDC
# Body length
median(na.omit(GDC.KO.length)) # median = 5.25
quantile(x = na.omit(GDC.KO.length), probs = c(0.25, 0.75)) # 4.075, 6.500
# HCW
median(na.omit(GDC.KO.HCW)) # median = 0.6
quantile(x = na.omit(GDC.KO.HCW), probs = c(0.25, 0.75)) # 0.4, 0.6

## RDN
# Body length
median(na.omit(RDN.KO.length)) # median = 6.5
quantile(x = na.omit(RDN.KO.length), probs = c(0.25, 0.75)) # 4.7, 9.1 
# HCW
median(na.omit(RDN.KO.HCW)) # median = 0.6
quantile(x = na.omit(RDN.KO.HCW), probs = c(0.25, 0.75)) # 0.6, 1.0

## TRT
# Body length
median(na.omit(TRT.KO.length)) # median = 4.3
quantile(x = na.omit(TRT.KO.length), probs = c(0.25, 0.75)) # 3.50, 6.85 
# HCW
median(na.omit(TRT.KO.HCW)) # median = 0.4
quantile(x = na.omit(TRT.KO.HCW), probs = c(0.25, 0.75)) # 0.4 0.7


#-------------------------------KG reaches--------------------------------#

## CED
# Body length
median(na.omit(CED.KG.length)) # median = 8.5
quantile(x = na.omit(CED.KG.length), probs = c(0.25, 0.75)) # 6.7, 11.6
# HCW
median(na.omit(CED.KG.HCW)) # median = 1.0
quantile(x = na.omit(CED.KG.HCW), probs = c(0.25, 0.75)) # 0.7, 1.0

## END
# Body length
median(na.omit(END.KG.length)) # median = 7.0
quantile(x = na.omit(END.KG.length), probs = c(0.25, 0.75)) # 5.325, 9.700
# HCW
median(na.omit(END.KG.HCW)) # median = 0.7
quantile(x = na.omit(END.KG.HCW), probs = c(0.25, 0.75)) # 0.6, 1.0

## GDC
# Body length
median(na.omit(GDC.KG.length)) # median = 3.45
quantile(x = na.omit(GDC.KG.length), probs = c(0.25, 0.75)) # 2.20, 5.15
# HCW
median(na.omit(GDC.KG.HCW)) # median = 0.4
quantile(x = na.omit(GDC.KG.HCW), probs = c(0.25, 0.75)) # 0.3, 0.6 

## RDN
# Body length
median(na.omit(RDN.KG.length)) # median = 9.3
quantile(x = na.omit(RDN.KG.length), probs = c(0.25, 0.75)) # 6.0, 11.2 
# HCW
median(na.omit(RDN.KG.HCW)) # median = 1.0
quantile(x = na.omit(RDN.KG.HCW), probs = c(0.25, 0.75)) # 0.6, 1.0

## TRT
# Body length
median(na.omit(TRT.KG.length)) # median = 5.55
quantile(x = na.omit(TRT.KG.length), probs = c(0.25, 0.75)) # 3.600, 8.725
# HCW
median(na.omit(TRT.KG.HCW)) # median = 0.6
quantile(x = na.omit(TRT.KG.HCW), probs = c(0.25, 0.75)) # 0.4, 1.0


#-------------------------------------------------------------------------#
#                                  Skew                                   #
#--------------------------------------------------------------------------

#-------------------------------KO reaches--------------------------------#

## CED
skewness(na.omit(CED.KO.length)) 
# skew = 0.2234721
skewness(na.omit(CED.KO.length))/(sqrt(6/length(na.omit(CED.KO.length)))) 
# t = 0.6704163
1 - pt(0.6704163, length(na.omit(CED.KO.length)) - 2) 
# P = 0.2527796

## END
skewness(na.omit(END.KO.length)) 
# skew = 0.2441932
skewness(na.omit(END.KO.length))/(sqrt(6/length(na.omit(END.KO.length))))
# t = 0.9351889
1 - pt(0.9351889, length(na.omit(END.KO.length)) - 2) 
# P = 0.1761548

## GDC
skewness(na.omit(GDC.KO.length)) 
# skew = 0.5926786
skewness(na.omit(GDC.KO.length))/(sqrt(6/length(na.omit(GDC.KO.length))))
# t = 1.810663
1 - pt(1.810663, length(na.omit(GDC.KO.length)) - 2) 
# P = 0.03787885

## RDN
skewness(na.omit(RDN.KO.length)) 
# skew = 0.5366889
skewness(na.omit(RDN.KO.length))/(sqrt(6/length(na.omit(RDN.KO.length))))
# t = 1.711244
1 - pt(1.711244, length(na.omit(RDN.KO.length)) - 2) 
# P = 0.04614459

## TRT
skewness(na.omit(TRT.KO.length)) 
# skew = 1.042935
skewness(na.omit(TRT.KO.length))/(sqrt(6/length(na.omit(TRT.KO.length))))
# t = 3.760357
1 - pt(3.760357, length(na.omit(TRT.KO.length)) - 2) 
# P = 0.0001656706


#-------------------------------KG reaches--------------------------------#

## CED
skewness(na.omit(CED.KG.length)) 
# skew = 0.01821037
skewness(na.omit(CED.KG.length))/(sqrt(6/length(na.omit(CED.KG.length))))
# t = 0.08378088
1 - pt(0.08378088, length(na.omit(CED.KG.length)) - 2) 
# P = 0.4666823

## END
skewness(na.omit(END.KG.length)) 
# skew = 0.1872325
skewness(na.omit(END.KG.length))/(sqrt(6/length(na.omit(END.KG.length))))
# t = 0.7719795
1 - pt(0.7719795, length(na.omit(END.KG.length)) - 2) 
# P = 0.2209736

## GDC
skewness(na.omit(GDC.KG.length)) 
# skew = 1.263575
skewness(na.omit(GDC.KG.length))/(sqrt(6/length(na.omit(GDC.KG.length))))
# t = 5.926694
1 - pt(5.926694, length(na.omit(GDC.KG.length)) - 2) 
# P = 1.306558e-08

## RDN
skewness(na.omit(RDN.KG.length)) 
# skew = -0.2048549
skewness(na.omit(RDN.KG.length))/(sqrt(6/length(na.omit(RDN.KG.length))))
# t = -1.137514
1 - pt(abs(-1.137514), length(na.omit(RDN.KG.length)) - 2) 
# P = 0.1284053

## TRT
skewness(na.omit(TRT.KG.length)) 
# skew = 0.5812517
skewness(na.omit(TRT.KG.length))/(sqrt(6/length(na.omit(TRT.KG.length))))
# t = 3.218826
1 - pt(3.218826, length(na.omit(TRT.KG.length)) - 2) 
# P = 0.0007620915


#-------------------------------------------------------------------------#
#                                Kurtosis                                 #
#--------------------------------------------------------------------------

#-------------------------------KO reaches--------------------------------#

## CED
kurtosis(na.omit(CED.KO.length)) 
# kurtosis = -0.9742846
kurtosis(na.omit(CED.KO.length))/(sqrt(24/length(na.omit(CED.KO.length))))
# t = -1.461427
1 - pt(abs(-1.461427), length(na.omit(CED.KO.length)) - 2) 
# P = 0.07495763

## END
kurtosis(na.omit(END.KO.length)) 
# kurtosis = -1.153727
kurtosis(na.omit(END.KO.length))/(sqrt(24/length(na.omit(END.KO.length))))
# t = -2.209219
1 - pt(abs(-2.209219), length(na.omit(END.KO.length)) - 2) 
# P = 0.01490869

## GDC
kurtosis(na.omit(GDC.KO.length)) 
# kurtosis = 0.2619579
kurtosis(na.omit(GDC.KO.length))/(sqrt(24/length(na.omit(GDC.KO.length))))
# t = 0.4001474
1 - pt(0.4001474, length(na.omit(GDC.KO.length)) - 2) 
# P = 0.3453133

## RDN
kurtosis(na.omit(RDN.KO.length)) 
# kurtosis = -0.6462719
kurtosis(na.omit(RDN.KO.length))/(sqrt(24/length(na.omit(RDN.KO.length))))
# t = -1.030326
1 - pt(abs(-1.030326), length(na.omit(RDN.KO.length)) - 2) 
# P = 0.1535312

## TRT
kurtosis(na.omit(TRT.KO.length)) 
# kurtosis = 0.2709354
kurtosis(na.omit(TRT.KO.length))/(sqrt(24/length(na.omit(TRT.KO.length))))
# t = 0.4884357
1 - pt(0.4884357, length(na.omit(TRT.KO.length)) - 2) 
# P = 0.3133238


#-------------------------------KG reaches--------------------------------#

## CED
kurtosis(na.omit(CED.KG.length)) 
# kurtosis = -1.214332
kurtosis(na.omit(CED.KG.length))/(sqrt(24/length(na.omit(CED.KG.length))))
# t = -2.793402
1 - pt(abs(-2.793402), length(na.omit(CED.KG.length)) - 2) 
# P = 0.003018606

## END
kurtosis(na.omit(END.KG.length)) 
# kurtosis = -0.7316508
kurtosis(na.omit(END.KG.length))/(sqrt(24/length(na.omit(END.KG.length))))
# t = -1.508337
1 - pt(abs(-1.508337), length(na.omit(END.KG.length)) - 2) 
# P = 0.06731063

## GDC
kurtosis(na.omit(GDC.KG.length)) 
# kurtosis = 1.593426
kurtosis(na.omit(GDC.KG.length))/(sqrt(24/length(na.omit(GDC.KG.length))))
# t = 3.736915
1 - pt(3.736915, length(na.omit(GDC.KG.length)) - 2) 
# P = 0.0001389518

## RDN
kurtosis(na.omit(RDN.KG.length)) 
# kurtosis = -1.269174
kurtosis(na.omit(RDN.KG.length))/(sqrt(24/length(na.omit(RDN.KG.length))))
# t = -3.523721
1 - pt(abs(-3.523721), length(na.omit(RDN.KG.length)) - 2) 
# P = 0.0002687418

## TRT
kurtosis(na.omit(TRT.KG.length)) 
# kurtosis = -0.8579491
kurtosis(na.omit(TRT.KG.length))/(sqrt(24/length(na.omit(TRT.KG.length))))
# t = -2.375554
1 - pt(abs(-2.375554), length(na.omit(TRT.KG.length)) - 2) 
# P = 0.009280946


#=========================================================================#
#                        Size Structure Comparisons                       #
#=========================================================================#

# Paired t-tests (with bootstrapped confidence intervals) to statistically
# compare size structure of P. hansoni between KO and KG reaches.

# Determine if the difference in median BL and HCW between KO and KG reaches
# is sigificantly different from 0.


#-------------------------------------------------------------------------#
#                             Paired  t-tests-BL                          #
#--------------------------------------------------------------------------

## Full data-BL-----------------------------------------------------------#

## Find the difference in median BL between KG and KO reaches
PHYL.BL.differences.full <- PHYL.data.BL.KG.full - PHYL.data.BL.KO.full

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.BL.differences.full)

## Shapiro-Wilkes Test
shapiro.test(PHYL.BL.differences.full) # Normal

# Set an empty vector of length 5000
boot.difference.BL.full <- numeric(5000)

# Bootstrap the differences in P. hansoni BLs
set.seed(1234)

for(x in 1:5000){
  PHYL.BL.resample.full <- sample(PHYL.BL.differences.full, 5, replace = TRUE)
  boot.difference.BL.full[x] <- mean(PHYL.BL.resample.full)
}

## Density plot (boostrapped)
plot(density(boot.difference.BL.full))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.BL.full[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.BL.full, c(0.025, 0.975))
# 95% CI = (-0.82, 1.87), no significant difference in median BL


## Final data-BL----------------------------------------------------------#

## Find the difference in median BL between KG and KO reaches
PHYL.BL.differences <- PHYL.data.BL.KG - PHYL.data.BL.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.BL.differences)

## Shapiro-Wilkes Test
shapiro.test(PHYL.BL.differences) # Normal

# Set an empty vector of length 5000
boot.difference.BL <- numeric(5000)

# bootstrap the differences in P. hansoni BLs
set.seed(1234)

for(x in 1:5000){
  PHYL.BL.resample <- sample(PHYL.BL.differences, 4, replace = TRUE)
  boot.difference.BL[x] <- mean(PHYL.BL.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.BL))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.BL[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.BL, c(0.025, 0.975))
# 95% CI = (0.350, 2.325), significant difference in median BL

# Interpretation: KG reaches shifted to larger median BL


#-------------------------------------------------------------------------#
#                             Paired  t-tests-HCW                         #
#--------------------------------------------------------------------------

# Determine if the difference in median HCW and HCW between KO and KG 
# reaches is sigificantly different from 0.

## Full data-HCW----------------------------------------------------------#

## Find the difference in median HCW between KG and KO reaches
PHYL.HCW.differences.full <- PHYL.data.HCW.KG.full - PHYL.data.HCW.KO.full

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.HCW.differences.full)

## Shapiro-Wilkes Test
shapiro.test(PHYL.HCW.differences.full) # Normal

# Set an empty vector of length 5000
boot.difference.HCW.full <- numeric(5000)

# Bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.HCW.resample.full <- sample(PHYL.HCW.differences.full, 5, replace = TRUE)
  boot.difference.HCW.full[x] <- mean(PHYL.HCW.resample.full)
}

## Density plot (boostrapped)
plot(density(boot.difference.HCW.full))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.HCW.full[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.HCW.full, c(0.025, 0.975))
# 95% CI = (-0.06, 0.32), no significant difference in median HCW


## Final data-HCW---------------------------------------------------------#

## Find the difference in median HCW between KG and KO reaches
PHYL.HCW.differences <- PHYL.data.HCW.KG - PHYL.data.HCW.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.HCW.differences)

## Shapiro-Wilkes Test
shapiro.test(PHYL.HCW.differences) # Normal

# Set an empty vector of length 5000
boot.difference.HCW <- numeric(5000)

# Bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.HCW.resample <- sample(PHYL.HCW.differences, 4, replace = TRUE)
  boot.difference.HCW[x] <- mean(PHYL.HCW.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.HCW))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.HCW[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.HCW, c(0.025, 0.975))
# 95% CI = (0.075, 0.350), significant difference in median HCW

# Interpretation: KG reaches shifted to larger median HCW


#-------------------------------------------------------------------------#
#                      Paired t-tests-Instar Body Length                  #
#--------------------------------------------------------------------------

# Determine if there are differences in median body length within instar
# groups between KO and KG reaches.

## S instar group---------------------------------------------------------#

## Find the difference in body.lengths of S instars between KG and KO reaches
PHYL.body.length.difference.S <- PHYL.body.length.S.KG - PHYL.body.length.S.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.body.length.difference.S)

## Shapiro-Wilkes Test
shapiro.test(PHYL.body.length.difference.S) # Normal

# Set an empty vector of length 5000
boot.difference.body.length.S <- numeric(5000)

# Bootstrap the differences in P. hansoni BLs within the S instar group
set.seed(1234)

for(x in 1:5000){
  PHYL.body.length.S.resample <- sample(PHYL.body.length.difference.S, 
                                        4, replace = TRUE)
  boot.difference.body.length.S[x] <- mean(PHYL.body.length.S.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.body.length.S))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.body.length.S[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.body.length.S, c(0.025, 0.975))
# 95% CI = (-0.8125, 0.1375), no significant difference in the median body
# length of S instars


## M instar group---------------------------------------------------------#

## Find the difference in body.lengths of M instars between KG and KO reaches
PHYL.body.length.difference.M <- PHYL.body.length.M.KG - PHYL.body.length.M.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.body.length.difference.M)

## Shapiro-Wilkes Test
shapiro.test(PHYL.body.length.difference.M) # Normal

# Set an empty vector of length 5000
boot.difference.body.length.M <- numeric(5000)

# Bootstrap the differences in P. hansoni BLs within the M instar group
set.seed(1234)

for(x in 1:5000){
  PHYL.body.length.M.resample <- sample(PHYL.body.length.difference.M, 
                                        4, replace = TRUE)
  boot.difference.body.length.M[x] <- mean(PHYL.body.length.M.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.body.length.M))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.body.length.M[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.body.length.M, c(0.025, 0.975))
# 95% CI = (-0.35, 0.50), no significant difference in the median body
# length of M instars


## L instar group---------------------------------------------------------#

## Find the difference in body.lengths of L instars between KG and KO reaches
PHYL.body.length.difference.L <- PHYL.body.length.L.KG - PHYL.body.length.L.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.body.length.difference.L)

## Shapiro-Wilkes Test
shapiro.test(PHYL.body.length.difference.L) # Normal

# Set an empty vector of length 5000
boot.difference.body.length.L <- numeric(5000)

# Bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.body.length.L.resample <- sample(PHYL.body.length.difference.L, 
                                        4, replace = TRUE)
  boot.difference.body.length.L[x] <- mean(PHYL.body.length.L.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.body.length.L))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.body.length.L[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.body.length.L, c(0.025, 0.975))
# 95% CI = (-0.6875, 0.5375), no significant difference in the median body
# length of L instars


#-------------------------------------------------------------------------#
#                      Paired t-tests-Instar Abundances                   #
#--------------------------------------------------------------------------

# Determine if there are differences in relative abundances within instar
# groups between KO and KG reaches.

## S instar group---------------------------------------------------------#

## Find the difference in abundances of S instars between KG and KO reaches
PHYL.abundance.difference.S <- PHYL.abundance.S.KG - PHYL.abundance.S.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.abundance.difference.S)

## Shapiro-Wilkes Test
shapiro.test(PHYL.abundance.difference.S)

# Set an empty vector of length 5000
boot.difference.abundance.S <- numeric(5000)

# bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.abundance.S.resample <- sample(PHYL.abundance.difference.S, 
                                      4, replace = TRUE)
  boot.difference.abundance.S[x] <- mean(PHYL.abundance.S.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.abundance.S))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.abundance.S[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.abundance.S, c(0.025, 0.975))
# 95% CI = (-17.358143, -7.932152), significant difference in the relative 
# abundances of S instars

# Interpretation: KG reaches had lower relative abundances of S instars


## M instar group---------------------------------------------------------#

## Find the difference in abundances of M instars between KG and KO reaches
PHYL.abundance.difference.M <- PHYL.abundance.M.KG - PHYL.abundance.M.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.abundance.difference.M)

## Shapiro-Wilkes Test
shapiro.test(PHYL.abundance.difference.M)

# Set an empty vector of length 5000
boot.difference.abundance.M <- numeric(5000)

# bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.abundance.M.resample <- sample(PHYL.abundance.difference.M, 
                                      4, replace = TRUE)
  boot.difference.abundance.M[x] <- mean(PHYL.abundance.M.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.abundance.M))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.abundance.M[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.abundance.M, c(0.025, 0.975))
# 95% CI = (-10.900023, 6.683878), no significant difference in the relative 
# abundances of M instars


## L instar group---------------------------------------------------------#

## Find the difference in abundances of L instars between KG and KO reaches
PHYL.abundance.difference.L <- PHYL.abundance.L.KG - PHYL.abundance.L.KO

## Q-Q plot
qqnorm.with.sim.bounds(PHYL.abundance.difference.L)

## Shapiro-Wilkes Test
shapiro.test(PHYL.abundance.difference.L)

# Set an empty vector of length 5000
boot.difference.abundance.L <- numeric(5000)

# bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  PHYL.abundance.L.resample <- sample(PHYL.abundance.difference.L, 
                                      4, replace = TRUE)
  boot.difference.abundance.L[x] <- mean(PHYL.abundance.L.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.abundance.L))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.abundance.L[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.abundance.L, c(0.025, 0.975))
# 95% CI = (5.293976, 25.872644), significant difference in the relative
# abundances of L instars

# Interpretation: KG reaches had more L instars


#=========================================================================#
#                               Stream Survey                             #
#==========================================================================

# Comparing environmental characteristics among focal streams.


## Initial normality tests
shapiro.test(survey.data$wetted.width) # Normal, but could be improved
shapiro.test(survey.data$depth) # Not normal
shapiro.test(survey.data$canopy.cover) # Not normal
shapiro.test(survey.data$CBOM) # Not normal
shapiro.test(survey.data$mean.CPUE) # Not normal


## Data transformations
survey.data$width.2 <- log(survey.data$wetted.width)
survey.data$depth.2 <- log(survey.data$depth)
survey.data$CBOM.2  <- log(survey.data$CBOM)


## Final normality tests
shapiro.test(survey.data$width.2) # Normal
shapiro.test(survey.data$depth.2) # Normal
shapiro.test(survey.data$CBOM.2) # Normal

# Canopy cover not transformed, requires non-standard transformation (cover^4)


## Univariate ANOVA for each environmental characteristic.

# To adjust for mutiple comparisons, Bonferroni correction will be used
# Standard alpha = 0.05
# For multiple comparisons (5), alpha = 0.01 will be used
# 0.01 = (0.05/5)

## Wetted-width
width.aov <- lm(width.2 ~ stream + reach, na.action = na.exclude, 
                data = survey.data)
anova(width.aov)
width.groups.1 <- HSD.test(width.aov, trt = "stream", group = TRUE)
width.groups.1 # Significant differences among streams
width.groups.2 <- HSD.test(width.aov, trt = "reach", group = TRUE)
width.groups.2 # Significant differences between reaches

## Check model assumptions
par(mfrow = c(2, 2))
plot(width.aov)
par(mfrow = c(1, 1))
hist(resid(width.aov))
plot(residuals(width.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(width.aov)), col = "red")

## Depth
depth.aov <- lm(depth.2 ~ stream + reach, na.action = na.exclude, 
                data = survey.data)
anova(depth.aov)
depth.groups.1 <- HSD.test(depth.aov, trt = "stream", group = TRUE)
depth.groups.1 # No significant differences among streams
depth.groups.2 <- HSD.test(depth.aov, trt = "reach", group = TRUE)
depth.groups.2 # No significant differences between reaches

## Check model assumptions
par(mfrow = c(2, 2))
plot(depth.aov)
par(mfrow = c(1, 1))
hist(resid(depth.aov))
plot(residuals(depth.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(depth.aov)), col = "red")

## Canopy cover
canopy.cover.aov <- lm(canopy.cover ~ stream + reach, na.action = na.exclude, 
                       data = survey.data)
anova(canopy.cover.aov)
canopy.cover.groups.1 <- HSD.test(canopy.cover.aov, trt = "stream", group = TRUE)
canopy.cover.groups.1 # Significant differences among streams
canopy.cover.groups.2 <- HSD.test(canopy.cover.aov, trt = "reach", group = TRUE)
canopy.cover.groups.2 # No significant differences between reaches

## Check model assumptions
par(mfrow = c(2, 2))
plot(canopy.cover.aov)
par(mfrow = c(1, 1))
hist(resid(canopy.cover.aov))
plot(residuals(canopy.cover.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(canopy.cover.aov)), col = "red")

## CBOM
CBOM.aov <- lm(CBOM.2 ~ stream + reach, na.action = na.exclude, 
               data = survey.data)
anova(CBOM.aov)
CBOM.groups.1 <- HSD.test(CBOM.aov, trt = "stream", group = TRUE)
CBOM.groups.1 # No significant differences among streams
CBOM.groups.2 <- HSD.test(CBOM.aov, trt = "reach", group = TRUE)
CBOM.groups.2 # No significant differences between reaches

## Check model assumptions
par(mfrow = c(2, 2))
plot(CBOM.aov)
par(mfrow = c(1, 1))
hist(resid(CBOM.aov))
plot(residuals(CBOM.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(CBOM.aov)), col = "red")

## mean CPUE
CPUE.aov <- lm(CPUE ~ stream + reach, na.action = na.exclude, 
                    data = survey.data)
anova(CPUE.aov)
CPUE.groups.1 <- HSD.test(CPUE.aov, trt = "stream", group = TRUE)
CPUE.groups.1 # No significant differences among streams
CPUE.groups.2 <- HSD.test(CPUE.aov, trt = "reach", group = TRUE)
CPUE.groups.2 # Significant differences between reaches

## Check model assumptions
par(mfrow = c(2, 2))
plot(CPUE.aov)
par(mfrow = c(1, 1))
hist(resid(CPUE.aov))
plot(residuals(CPUE.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(CPUE.aov)), col = "red")


#=========================================================================#
#                     Killifish Predation & Size Classes                  #
#==========================================================================

# Evaluate (1) if P. hansoni are present in more killifish gut contents in KO
# reaches, and (2) if there is a size-selective component to killifish 
# predation on P. hansoni


## Predation Success------------------------------------------------------#

## Find the difference in percent success between KO and KG reaches
FISH.predation.success <- FISH.predation.success.KG - FISH.predation.success.KO

## Q-Q plot
qqnorm.with.sim.bounds(FISH.predation.success)

## Shapiro-Wilkes Test
shapiro.test(FISH.predation.success) # Normal

# Set an empty vector of length 5000
boot.difference.predation.success <- numeric(5000)

# Bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  FISH.predation.success.resample <- sample(FISH.predation.success, 
                                                  3, replace = TRUE)
  boot.difference.predation.success[x] <- mean(FISH.predation.success.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.predation.success))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.predation.success[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.predation.success, c(0.025, 0.975))
# 95% CI = (-0.3333333, 4.0000000), no significant difference in percentage of
# successful predation on P. hansoni by killifish

# Interpretation: No evidence for stronger predation by killifish on 
# P. hansoni between KO and KG reaches


## Size-Selective Predation-----------------------------------------------#

## Find the difference in median HCW of consumed P. hansoni between KG and 
## KO reaches
FISH.predation.HCW <- FISH.predation.HCW.KG - FISH.predation.HCW.KO

# Set an empty vector of length 5000
boot.difference.predation.HCW <- numeric(5000)

# Bootstrap the differences in P. hansoni HCWs
set.seed(1234)

for(x in 1:5000){
  FISH.HCW.resample <- sample(FISH.predation.HCW, 
                                    3, replace = TRUE)
  boot.difference.predation.HCW[x] <- mean(FISH.HCW.resample)
}

## Density plot (boostrapped)
plot(density(boot.difference.predation.HCW))

## Q-Q plot (bootstrapped)
qqnorm.with.sim.bounds(boot.difference.predation.HCW[1:5000])

## 95% confidence interval (CI)
quantile(boot.difference.predation.HCW, c(0.025, 0.975))
# 95% CI = (-0.01375, 0.15950), no significant difference in median HCW of
# consumed P. hansoni

# Interpretation: No evidence for size-selective predation driving observed
# differences in P. hansoni size structure


## Killifish Size Classes-------------------------------------------------#

size.class.aov <- lm(log(mean.CPUE + 1) ~ fish.SC:reach, 
										 na.action = na.exclude, 
										 data = fish.SC.data)
anova(size.class.aov)

## Check model assumptions
par(mfrow = c(2, 2))
plot(size.class.aov)
par(mfrow = c(1, 1))
hist(resid(size.class.aov))
plot(residuals(size.class.aov))
abline(h = 0, lty = 2)
lines(smooth.spline(residuals(size.class.aov)), col = "red")

#=========================================================================#
#                                   Figures                               #
#==========================================================================

## Boxplot Figure---------------------------------------------------------#

## Set figure parameters
par(mfrow = c(2, 1), las = 1)
par(mai = c(1.0, 0.75, 0.1, 0.1), omi = c(0.05, 0.05, 0.05, 0.05))

# KO = gray75
# KG = gray45

# Body length panel
boxplot(CED.KO.length, CED.KG.length, END.KO.length, END.KG.length, 
				GDC.KO.length, GDC.KG.length, RDN.KO.length, RDN.KG.length, 
				TRT.KO.length, TRT.KG.length,
        names = c("KO", "KG", "KO", "KG", "KO", "KG", "KO", "KG", "KO", "KG"),
        col = c("gray75", "gray45", "gray75", "gray45", "gray75", "gray45",
                "gray75", "gray45", "gray75", "gray45"),
				na.action = na.omit)
mtext(text = "CED", side = 1, line = 2.0, adj = 0.1, cex = 1.2)
mtext(text = "END", side = 1, line = 2.0, adj = 0.3, cex = 1.2)
mtext(text = "GDC", side = 1, line = 2.0, adj = 0.5, cex = 1.2)
mtext(text = "RDN", side = 1, line = 2.0, adj = 0.7, cex = 1.2)
mtext(text = "TRT", side = 1, line = 2.0, adj = 0.9, cex = 1.2)
mtext(text = expression(bold("a")), side = 3, line = -1.1, adj = 0.025, 
      cex = 1.25)
title(ylab = "Body Length (mm)", cex.axis = 1.15, cex.lab = 1.25, line = 2.5)
box(lwd = 2)

# HCW panel
boxplot(CED.KO.HCW, CED.KG.HCW, END.KO.HCW, END.KG.HCW, 
				GDC.KO.HCW, GDC.KG.HCW, RDN.KO.HCW, RDN.KG.HCW, 
				TRT.KO.HCW, TRT.KG.HCW,
        names = c("KO", "KG", "KO", "KG", "KO", "KG", "KO", "KG", "KO", "KG"),
        col = c("gray75", "gray45", "gray75", "gray45", "gray75", "gray45",
                "gray75", "gray45", "gray75", "gray45"),
				na.action = na.omit)
mtext(text = "CED", side = 1, line = 2.0, adj = 0.1, cex = 1.2)
mtext(text = "END", side = 1, line = 2.0, adj = 0.3, cex = 1.2)
mtext(text = "GDC", side = 1, line = 2.0, adj = 0.5, cex = 1.2)
mtext(text = "RDN", side = 1, line = 2.0, adj = 0.7, cex = 1.2)
mtext(text = "TRT", side = 1, line = 2.0, adj = 0.9, cex = 1.2)
mtext(text = expression(bold("b")), side = 3, line = -1.1, adj = 0.025, 
      cex = 1.25)
title(ylab = "HCW (mm)", cex.axis = 1.15, cex.lab = 1.25, line = 2.5)
title(xlab = "Focal Streams",cex.lab = 1.40, line = 3.5)
box(lwd = 2)


## Body Length & Instar Relative Abundance Figure-------------------------#

# Get the mean (of the median) and standard error of body length
PHYL.body.length.summary <- ddply(PHYL.body.length, c("instar.group", 
                                  "reach"), summarise,
                                  N      = sum(!is.na(length)),
                                  median = median(length, na.rm = TRUE),
                                  sd     = sd(length, na.rm = TRUE),
                                  se     = 1.25 * sd / sqrt(N)
)
PHYL.body.length.summary


# Get the mean and standard error of relative abundances
PHYL.abundance.summary <- ddply(PHYL.abundance, c("instar.group", 
                                "reach"), summarise,
                                N    = sum(!is.na(relative.abundance)),
                                mean = mean(relative.abundance, na.rm = TRUE),
                                sd   = sd(relative.abundance, na.rm = TRUE),
                                se   = sd / sqrt(N)
)
PHYL.abundance.summary


## Define column widths (relative abundance) and heigths (body length)
KO.widths  <- c(30.8, 36.4, 32.8)
KO.heights <- c(4.150, 6.200, 10.725)
KG.widths  <- c(18.1, 34.6, 47.3)
KG.heights <- c(3.725, 6.275, 10.675)

## Set figure parameters
par(mfrow = c(2, 1))
par(mai = c(0.75, 0.75, 0.1, 0.1), omi = c(0.05, 0.05, 0.05, 0.05))

# KO panel
barplot(KO.heights, KO.widths, space = 0, axes = FALSE, ylim = c(0, 12),
        col = "gray75")
axis(1, las = 1, at = c(0, 25, 50, 75, 100), cex.axis = 1.15, tick = TRUE)
axis(2, las = 1, at = c(0, 3, 6, 9, 12), cex.axis = 1.15, tick = TRUE)
# Instar group labels
text(15.38, 2.015, "S", cex = 1.5) 
text(48.96, 3.155, "M", cex = 1.5) 
text(83.58, 5.33, "L", cex = 1.5) 
# Mean +/- SE (body length)
text(15.38, 4.53, expression(paste("4.15", phantom(.)%+-%phantom(.), 
                                   "0.18 (mm)")), cex = 0.85) 
text(48.96, 6.81, expression(paste("6.20", phantom(.)%+-%phantom(.), 
                                   "0.30 (mm)")), cex = 0.85) 
text(83.58, 11.16, expression(paste("10.73", phantom(.)%+-%phantom(.), 
                                    "0.15 (mm)")), cex = 0.85)
# Mean +/- SE (abundances)
text(15.38, 0.5, expression(paste("30.8", phantom(.)%+-%phantom(.), 
                                  "7.3 (%)")), cex = 0.85) 
text(48.96, 0.5, expression(paste("36.4", phantom(.)%+-%phantom(.), 
                                  "3.9 (%)")), cex = 0.85) 
text(83.58, 0.5, expression(paste("32.8", phantom(.)%+-%phantom(.), 
                                  "5.8 (%)")), cex = 0.85)
title(ylab = "Body Length (mm)", cex.axis = 1.15, cex.lab = 1.25, line = 2.5)
mtext(text = expression(bold("a")), side = 3, line = -1.1, adj = 0.05, 
      cex = 1.25)
box(lwd = 2)

# KG panel
barplot(KG.heights, KG.widths, space = 0, axes = FALSE, ylim = c(0, 12),
        col = "gray45")
axis(1, las = 1, at = c(0, 25, 50, 75, 100), cex.axis = 1.25, tick = TRUE)
axis(2, las = 1, at = c(0, 3, 6, 9, 12), cex.axis = 1.25, tick = TRUE)
text(9.055, 1.875, "S", cex = 1.5) 
text(35.395, 3.17, "M", cex = 1.5) 
text(76.340, 5.32, "L", cex = 1.5) 
# Mean +/- SE (body length)
text(9.055, 4.25, expression(paste("3.73", phantom(.)%+-%phantom(.), 
                                   "0.34 (mm)")), cex = 0.85) 
text(35.395, 6.84, expression(paste("6.28", phantom(.)%+-%phantom(.), 
                                    "0.31 (mm)")), cex = 0.85) 
text(76.340, 11.14, expression(paste("10.68", phantom(.)%+-%phantom(.), 
                                     "0.38 (mm)")), cex = 0.85)
# Mean +/- SE (abundances)
text(9.055, 0.5, expression(paste("18.1", phantom(.)%+-%phantom(.), 
                                   "9.0 (%)")), cex = 0.85) 
text(35.395, 0.5, expression(paste("34.6", phantom(.)%+-%phantom(.), 
                                   "3.9 (%)")), cex = 0.85) 
text(76.340, 0.5, expression(paste("47.3", phantom(.)%+-%phantom(.), 
                                   "6.3 (%)")), cex = 0.85)
title(xlab = "Relative Abundance (% of Population)", 
      ylab = "Body Length (mm)", cex.axis = 1.05, cex.lab = 1.25, line = 2.5)
mtext(text = expression(bold("b")), side = 3, line = -1.1, adj = 0.05, 
      cex = 1.25)
box(lwd = 2)


## Killifish Predation Figure---------------------------------------------#

# Values for CPUE/size class 
SC    <- c("J", "S", "M", "L", "XL")
X     <- c(1, 2, 3, 4, 5)
KO    <- c(0.000, 16.240, 36.646, 29.974, 17.140)
KO.SE <- c(0, 5.031859, 5.303962, 3.655130, 1.646086)
KG    <- c(2.840, 26.606, 37.746, 25.240, 7.546)
KG.SE <- c(1.286313, 9.961714, 10.516274, 2.145833, 3.761651)
y.range <- c(0, 50)

## Set figure parameters
par(mfrow = c(1, 1))
par(mai = c(0.80, 1.0, 0.1, 0.1), omi = c(0.05, 0.05, 0.05, 0.05))

## Plot mean CPUE by size class by reach
plot(KO, pch = 15, type = "o", ylim = c(0, 50), axes = FALSE, 
		 ann = FALSE, lwd = 2, col = "gray75")
axis(1, at = 1:5, lab = c("J", "S", "M", "L", "XL"), cex.axis = 1.35)
axis(2, las = 1, at = 10 * 0:y.range[2], cex.axis = 1.35)
lines(KG, type = "o", pch = 5, lty = 2, lwd = 2, col = "gray45")
title(xlab = "Killifish Size Class", cex.lab = 1.55)
title(ylab = "Abundance (CPUE)", cex.lab = 1.55, line = 3.5)

arrows(axis(1, at = 1:5, lab = c("J", "S", "M", "L", "XL"), cex.axis = 1.45),
			 KO - KO.SE, axis(1, at = 1:5, lab = c("J", "S", "M", "L", "XL"), cex.axis = 1.45), 
			 KO + KO.SE, length = 0.05, angle = 90, code = 3, lwd = 3, col = "gray75")
arrows(axis(1, at = 1:5, lab = c("J", "S", "M", "L", "XL"), cex.axis = 1.45), 
			 KG - KG.SE, axis(1, at = 1:5, lab = c("J", "S", "M", "L", "XL"), cex.axis = 1.45), 
			 KG + KG.SE, length = 0.05, angle = 90, code = 3, lwd = 3, col = "gray45")
box(lwd = 2)

#=========================================================================#
#                                End of Script                            #
#=========================================================================#